@@ -177,6 +177,7 @@ PTM_MarkerFinder <- function(data,
             .PTM_MarkerFinder_writeMGF(data[[i]], mgfFilename, 
                 pattern=paste(data[[i]]$mZ[idx[b]], data[[i]]$intensity[idx[b]]))
             }
+
            r <- cbind(scans=data[[i]]$scans, 
                 mZ=data[[i]]$mZ[idx[b]],
                 markerIonMZ=mZmarkerIons[b],
@@ -184,9 +185,12 @@ PTM_MarkerFinder <- function(data,
                 markerIonMzError=mZmarkerIons[b]-data[[i]]$mZ[idx[b]],
                 markerIonPpmError=1e+06 * (mZmarkerIons[b]-data[[i]]$mZ[idx[b]])/data[[i]]$mZ[idx[b]],
                 query=i,
-                pepmass=data[[i]]$pepmass
+                pepmass=data[[i]]$pepmass,
+                peptideSequence=data[[i]]$peptideSequence,
+                modification=data[[i]]$modification
                 )
 
+
            rr<-rbind(rr,r)
 
             split.screen(c(3,1))
@@ -322,10 +326,33 @@ PTM_MarkerFinder <- function(data,
         }
     }
     close.screen(all.screens = TRUE)
-
-    return(as.data.frame(rr))
+    
+    # TODO(cp): make a S3 class
+    rr <- as.data.frame(rr)
+   
+    rr$markerIonIntensity <- as.numeric(levels(rr$markerIonIntensity))[rr$markerIonIntensity]
+    rr$mZ <- as.numeric(levels(rr$mZ))[rr$mZ]
+    rr$pepmass <- as.numeric(levels(rr$pepmass))[rr$pepmass]
+    rr$markerIonMZ <- as.numeric(levels(rr$markerIonMZ))[rr$markerIonMZ]
+    rr$markerIonMzError <- as.numeric(levels(rr$markerIonMzError))[rr$markerIonMzError]
+    
+    return(rr)
 }
 
+ptmmf <- setClass("ptmmf",
+                  slots=c(
+                          scans="character",
+                          mZ="numeric",
+                          markerIonMZ="numeric", 
+                          markerIonIntensity="numeric", 
+                          markerIonMzError="numeric",
+                          markerIonPpmError="numeric", 
+                          relativeFragmentIntensity="numeric", 
+                          query ="character", 
+                          pepmass="numeric", 
+                          peptideSequence="character",
+                          modification="character")
+)
 
 # code for screening multiple modifications
 # by Paolo <paolo.nanni@fgcz.uzh.ch> and Christian <cp@fgcz.ethz.ch>, March 2013
@@ -345,7 +372,8 @@ PTM_MarkerFinder <- function(data,
         op<-par(mfrow=c(4,5), mar=c(4,4,3,1)); 
         dump <- lapply(split(s,s$query), 
 
-    function(x){ plot(x$mZ, x$markerIonIntensity, 
+    function(x){ 
+      plot(x$mZ, x$markerIonIntensity, 
         type='h',
         col='lightblue',
         cex=2,
@@ -353,7 +381,8 @@ PTM_MarkerFinder <- function(data,
         ylim=range(s$markerIonIntensity),
         log='y',
         main=paste("scan=",unique(x$scans),"/query=", unique(x$query), sep='')); 
-        text(x$mZ, x$markerIonIntensity,round(x$mZ,1),col='red',cex=0.7)})
+        text(x$mZ, x$markerIonIntensity,round(x$mZ,1),col='red',cex=0.7)
+      })
 
 par(op)
 
@@ -368,17 +397,17 @@ par(op)
 
 op<-par(mfrow=c(1,1), mar=c(5,5,5,5)); 
 
-boxplot(s$markerIonIntensity ~ s$markerIonMZ,
+boxplot(s$markerIonIntensity ~ as.factor(s$markerIonMZ),
     log='y',
     main='summary marker ion intensity distribution',
     xlab='markerIon m/z', ylab='log10 based marker ion intensity')
 box()
 
-boxplot(markerIonPpmError~as.factor(scans),
-    data=s, 
-    main='marker ions PPM error summary',
-    xlab='scan number', ylab='ppm error')
-abline(h=0.0,col='grey')
+#boxplot(markerIonPpmError~(scans),
+#    data=s, 
+#    main='marker ions PPM error summary',
+#    xlab='scan number', ylab='ppm error')
+#abline(h=0.0,col='grey')
 
 par(mfrow=c(1,1));
 barplot(tapply(s$markerIonIntensity, s$scans, FUN=sum),log='y',
@@ -404,7 +433,11 @@ PTM_MarkerFinder_util<-function(dataFileName,
         minNumberIons=minNumberIons,
         itol_ppm=itol_ppm)
 
-    load(paste(config$dataFileName, "RData", sep='.'))
+    
+    datFilename <- paste(config$dataFileName, "RData", sep='.')
+    
+    message(paste("load file", datFilename, "..."))
+    load(datFilename)
 
     pdf(paste(config$dataFileName, "pdf", sep='.'), 19, 12)
     s<-PTM_MarkerFinder(data=get(config$dataFileName), 
@@ -432,7 +465,10 @@ PTM_MarkerFinder_util<-function(dataFileName,
     dev.off()
 
     if ( nrow(s) > 1 & write_csv==TRUE ){
-        w<-reshape(s[, c(1,7,8,3,4)], direction='wide', timevar="markerIonMZ", idvar=c('scans','query','pepmass'))
+        w<-reshape(s[, c(1,7,8,3,4,9,10)], 
+		direction='wide', 
+		timevar="markerIonMZ", 
+		idvar=c('scans', 'query', 'pepmass', 'peptideSequence', 'modification'))
 
         write.table(w, file=paste(config$dataFileName, "csv", sep='.'),
             sep=',', row.names=FALSE, col.names=TRUE, quote=FALSE)
